{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": "${\n  return [\n    {\n      \"entry\": inputs.query_feature_bc_matrices_h5,\n      \"entryname\": inputs.query_feature_bc_matrices_h5.basename,\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.reference_marker_heatmap_file,\n      \"entryname\": inputs.reference_marker_heatmap_file.basename,\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.reference_annotation_metadata_file,\n      \"entryname\": inputs.reference_annotation_metadata_file.basename,\n      \"writable\": true\n    },\n    {\n      \"entry\": inputs.reference_expression_matrix_file,\n      \"entryname\": inputs.reference_expression_matrix_file.basename,\n      \"writable\": true\n    }\n  ]\n}\n"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/altanalyze:v0.0.6"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#altanalyze-cellharmony.cwl/align_by/centroid",
                                "#altanalyze-cellharmony.cwl/align_by/cell"
                            ]
                        }
                    ],
                    "default": "centroid",
                    "inputBinding": {
                        "prefix": "--referenceType",
                        "position": 11
                    },
                    "doc": "Aligning to cluster centroid or cell\n",
                    "id": "#altanalyze-cellharmony.cwl/align_by"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\n\n# Copy altanalyze to the current working directory\n# which is mount with -rw- permissions. Otherwise \n# we can't download anything because by default\n# container is run by cwltool with --read-only\n\ncp -r /opt/altanalyze .\n\nGENOME_DATA=$0\n\nGENOME_DATA_BASENAME=`basename ${GENOME_DATA}`\nARR=(${GENOME_DATA_BASENAME//__/ })\nENSEMBL_VERSION=${ARR[0]}\nSPECIES=${ARR[1]}\n\necho \"Load ${SPECIES} from ${ENSEMBL_VERSION}\"\nln -s ${GENOME_DATA} ./altanalyze/AltDatabase/${ENSEMBL_VERSION}\n\npython ./altanalyze/AltAnalyze.py --species ${SPECIES} \\\n--platform RNASeq --cellHarmony yes ${@:1}\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash script to run AltAnalyze CellHarmony with provided parameters\n",
                    "id": "#altanalyze-cellharmony.cwl/bash_script"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.4,
                    "inputBinding": {
                        "prefix": "--correlationCutoff",
                        "position": 12
                    },
                    "doc": "Pearson correlation threshold\n",
                    "id": "#altanalyze-cellharmony.cwl/correlation_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 1.5,
                    "inputBinding": {
                        "prefix": "--fold",
                        "position": 14
                    },
                    "doc": "Differential expression fold-change threshold.\nApplied if running differential expression\n",
                    "id": "#altanalyze-cellharmony.cwl/diff_expr_fold_change_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--pval",
                        "position": 15
                    },
                    "doc": "Cutoff value for P-value of P-adjusted-value.\nApplied if running differential expression\n",
                    "id": "#altanalyze-cellharmony.cwl/diff_expr_p_value_threshold"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "Ensembl database from the altanalyze-prepare-genome.cwl pipeline.\n--species parameter and Ensembl version will be resolved based on\nthis folder basename\n",
                    "id": "#altanalyze-cellharmony.cwl/genome_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--performDiffExp",
                        "position": 13,
                        "valueFrom": "$(self?\"yes\":\"no\")"
                    },
                    "doc": "Perform differential expression analysis\n",
                    "id": "#altanalyze-cellharmony.cwl/perform_diff_expression"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--input"
                    },
                    "doc": "Query dataset. Feature-barcode matrices in HDF5 format. Output from Cell Ranger\n",
                    "id": "#altanalyze-cellharmony.cwl/query_feature_bc_matrices_h5"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 9,
                        "prefix": "--labels"
                    },
                    "doc": "Reference annotation metadata file produced by altanalyze-icgs.cwl pipeline\n",
                    "id": "#altanalyze-cellharmony.cwl/reference_annotation_metadata_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "prefix": "--referenceFull"
                    },
                    "doc": "Reference expression matrix file produced by altanalyze-icgs.cwl pipeline\n",
                    "id": "#altanalyze-cellharmony.cwl/reference_expression_matrix_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8,
                        "prefix": "--reference"
                    },
                    "doc": "Reference marker gene heatmap file produced by altanalyze-icgs.cwl pipeline\n",
                    "id": "#altanalyze-cellharmony.cwl/reference_marker_heatmap_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--adjp",
                        "position": 16,
                        "valueFrom": "$(self?\"yes\":\"no\")"
                    },
                    "doc": "Use adjusted P-value for differentially expressed genes threshold.\nApplied if running differential expression\n",
                    "id": "#altanalyze-cellharmony.cwl/use_adjusted_pvalue"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "stdout": "altanalyze_cellharmony_stdout.log",
            "stderr": "altanalyze_cellharmony_stderr.log",
            "doc": "Runs AltAnalyze cellHarmony for 10X Genomics data\n",
            "id": "#altanalyze-cellharmony.cwl",
            "http://schema.org/name": "altanalyze-cellharmony",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/altanalyze-cellharmony.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                },
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Salomonis Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Stuart Hay",
                                            "http://schema.org/email": "mailto:haysb91@gmail.com"
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "CellHarmony is a cell-matching algorithm designed to identify a cell's most similar\nanalogue in a distinct single-cell RNA-Seq (scRNA-Seq) dataset and find differentially\nexpressed genes in each cell population.\n",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "cellHarmony"
                    },
                    "id": "#altanalyze-cellharmony.cwl/cellharmony_data"
                },
                {
                    "type": "File",
                    "id": "#altanalyze-cellharmony.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "altanalyze_cellharmony_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#altanalyze-cellharmony.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "altanalyze_cellharmony_stdout.log"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Folder to compressed",
                    "id": "#tar-compress.cwl/folder_to_compress"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Compressed folder",
                    "id": "#tar-compress.cwl/compressed_folder"
                }
            ],
            "baseCommand": [
                "tar"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.folder_to_compress.path.split(\"/\").slice(0,-1).join(\"/\"))",
                    "prefix": "-C"
                },
                "-czvf",
                {
                    "valueFrom": "$(inputs.folder_to_compress.basename + \".tar.gz\")"
                },
                "."
            ],
            "doc": "Compresses input directory to tar.gz\n",
            "id": "#tar-compress.cwl",
            "http://schema.org/name": "tar-compress",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/tar-compress.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "sc_rnaseq_sample": [
                    "single-cell-preprocess-cellranger.cwl",
                    "cellranger-aggr.cwl"
                ],
                "altanalyze_icgs_sample": [
                    "altanalyze-icgs.cwl"
                ],
                "altanalyze_prepare_genome_sample": [
                    "altanalyze-prepare-genome.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/align_by/centroid",
                                "#main/align_by/cell"
                            ]
                        }
                    ],
                    "default": "centroid",
                    "label": "Aligning algorithm",
                    "doc": "Aligning to cluster centroid or cell",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/align_by"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.4,
                    "label": "Pearson correlation threshold",
                    "doc": "Pearson correlation threshold",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/correlation_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 1.5,
                    "label": "Differential expression fold-change threshold",
                    "doc": "Differential expression fold-change threshold.\nApplied if running differential expression\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/diff_expr_fold_change_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "label": "Cutoff value for P-value of P-adjusted-value",
                    "doc": "Cutoff value for P-value of P-adjusted-value.\nApplied if running differential expression\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/diff_expr_p_value_threshold"
                },
                {
                    "type": "File",
                    "label": "scRNA-Seq Cell Ranger Experiment",
                    "doc": "Filtered feature-barcode matrices in HDF5 format from cellranger count or aggr results",
                    "sd:upstreamSource": "sc_rnaseq_sample/filtered_feature_bc_matrix_h5",
                    "sd:localLabel": true,
                    "id": "#main/filtered_feature_bc_matrix_h5"
                },
                {
                    "type": "Directory",
                    "label": "AltAnalyze Prepare Genome Experiment",
                    "doc": "Ensembl database from the altanalyze-prepare-genome.cwl pipeline",
                    "sd:upstreamSource": "altanalyze_prepare_genome_sample/genome_data",
                    "sd:localLabel": true,
                    "id": "#main/genome_data"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Perform differential expression analysis",
                    "doc": "Perform differential expression analysis",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/perform_diff_expression"
                },
                {
                    "type": "File",
                    "label": "AltAnalyze ICGS Experiment",
                    "doc": "AltAnalyze ICGS Annotation Metadata",
                    "sd:upstreamSource": "altanalyze_icgs_sample/icgs_annotation_metadata_file",
                    "sd:localLabel": true,
                    "id": "#main/reference_annotation_metadata_file"
                },
                {
                    "type": "File",
                    "label": "AltAnalyze ICGS Experiment",
                    "doc": "AltAnalyze ICGS Expression Matrix",
                    "sd:upstreamSource": "altanalyze_icgs_sample/expression_matrix_file",
                    "sd:localLabel": true,
                    "id": "#main/reference_expression_matrix_file"
                },
                {
                    "type": "File",
                    "label": "AltAnalyze ICGS Experiment",
                    "doc": "AltAnalyze ICGS Marker Gene Heatmap",
                    "sd:upstreamSource": "altanalyze_icgs_sample/icgs_marker_heatmap_file",
                    "sd:localLabel": true,
                    "id": "#main/reference_marker_heatmap_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "label": "Use adjusted P-value for differentially expressed genes threshold",
                    "doc": "Use adjusted P-value for differentially expressed genes threshold.\nApplied if running differential expression\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/use_adjusted_pvalue"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/altanalyze_cellharmony/stderr_log",
                    "label": "stderr log generated by altanalyze cellharmony",
                    "doc": "stderr log generated by altanalyze cellharmony\n",
                    "id": "#main/cellharmony_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/altanalyze_cellharmony/stdout_log",
                    "label": "stdout log generated by altanalyze cellharmony",
                    "doc": "stdout log generated by altanalyze cellharmony\n",
                    "id": "#main/cellharmony_stdout_log"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_cellharmony_data_folder/compressed_folder",
                    "label": "Compressed folder with AltAnalyze CellHarmony results",
                    "doc": "Compressed folder with AltAnalyze CellHarmony results\n",
                    "id": "#main/compressed_cellharmony_data_folder"
                }
            ],
            "steps": [
                {
                    "run": "#altanalyze-cellharmony.cwl",
                    "in": [
                        {
                            "source": "#main/align_by",
                            "id": "#main/altanalyze_cellharmony/align_by"
                        },
                        {
                            "source": "#main/correlation_threshold",
                            "id": "#main/altanalyze_cellharmony/correlation_threshold"
                        },
                        {
                            "source": "#main/diff_expr_fold_change_threshold",
                            "id": "#main/altanalyze_cellharmony/diff_expr_fold_change_threshold"
                        },
                        {
                            "source": "#main/diff_expr_p_value_threshold",
                            "id": "#main/altanalyze_cellharmony/diff_expr_p_value_threshold"
                        },
                        {
                            "source": "#main/genome_data",
                            "id": "#main/altanalyze_cellharmony/genome_data"
                        },
                        {
                            "source": "#main/perform_diff_expression",
                            "id": "#main/altanalyze_cellharmony/perform_diff_expression"
                        },
                        {
                            "source": "#main/filtered_feature_bc_matrix_h5",
                            "id": "#main/altanalyze_cellharmony/query_feature_bc_matrices_h5"
                        },
                        {
                            "source": "#main/reference_annotation_metadata_file",
                            "id": "#main/altanalyze_cellharmony/reference_annotation_metadata_file"
                        },
                        {
                            "source": "#main/reference_expression_matrix_file",
                            "id": "#main/altanalyze_cellharmony/reference_expression_matrix_file"
                        },
                        {
                            "source": "#main/reference_marker_heatmap_file",
                            "id": "#main/altanalyze_cellharmony/reference_marker_heatmap_file"
                        },
                        {
                            "source": "#main/use_adjusted_pvalue",
                            "id": "#main/altanalyze_cellharmony/use_adjusted_pvalue"
                        }
                    ],
                    "out": [
                        "#main/altanalyze_cellharmony/cellharmony_data",
                        "#main/altanalyze_cellharmony/stdout_log",
                        "#main/altanalyze_cellharmony/stderr_log"
                    ],
                    "id": "#main/altanalyze_cellharmony"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/altanalyze_cellharmony/cellharmony_data",
                            "id": "#main/compress_cellharmony_data_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_cellharmony_data_folder/compressed_folder"
                    ],
                    "id": "#main/compress_cellharmony_data_folder"
                }
            ],
            "label": "AltAnalyze CellHarmony",
            "doc": "AltAnalyze CellHarmony\n======================",
            "id": "#main",
            "http://schema.org/name": "AltAnalyze CellHarmony",
            "http://schema.org/alternateName": "Runs cell-level matching and comparison of single-cell transcriptomes for AltAnalyze ICGS, Cell Ranger Count Gene Expression or Cell Ranger Aggregate experiments",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/altanalyze-cellharmony.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
